/*
 * Data Auxiliary header (used by Data Auxiliary codecs)
 * Copyright (c) 2012
 *
 * This file is part of FFmpeg.
 *
 * FFmpeg is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * FFmpeg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with FFmpeg; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

/**
 * @file data_auxiliary.h
 */

#ifndef AVCODEC_DATA_AUXILIARY_H
#define AVCODEC_DATA_AUXILIARY_H


#define DATA_AUX_MAX_ENTRIES 	32			// Number of Data Aux entries in the output format struct
#define DATA_AUX_ENTRY_SIZE		2000		// Size in bytes of a Data Aux entry


//#define DEBUG_DATA_AUXILIARY_H


/*	--- Enums */
typedef enum {
	DataAuxIdUnknownEn,
	DataAuxIdCdp708En,
	DataAuxIdAfdEn,
} DataAuxIdEnTp;							// Id for each type of Data Auxiliary


/*	--- Structs */
#pragma pack(push,1)
typedef struct DataAuxHeaderEntryTp {		// Output format header entry
	DataAuxIdEnTp 		type;
	uint32_t			offset;
	uint32_t			length;
} DataAuxHeaderEntryTp;

typedef struct DataAuxTp {											// Output format complete
	uint16_t			 entryCt;									// Number of data auxiliaries present
	DataAuxHeaderEntryTp entryVc[DATA_AUX_MAX_ENTRIES];				// Headers
	uint8_t				 padding[6];								// Padding bytes to let header align to void*
	uint8_t				 dataVc[DATA_AUX_MAX_ENTRIES * DATA_AUX_ENTRY_SIZE]; // Data space for void* aligned payload
} DataAuxTp;
#pragma pack(pop)




#endif
