#!/bin/bash

# ----------------------------------------------------------------------
# Globals
# ----------------------------------------------------------------------

Vers="(v1)"
ArgCt=$#
GroupDir="../.."

ScriptDir=$(dirname $0 | tr -d \\r)
ScriptName=$(basename $0 .sh)

# First test for qmake debug/release mode flags.
if [ $# -gt 0 ]; then
   if [ "$1" = "debug" ];   then QmakeReleaseDebug=debug;   shift; fi;
   if [ "$1" = "release" ]; then QmakeReleaseDebug=release; shift; fi;
fi

# Get the group system definitions and source them.
GroupDefs=$ScriptDir/group-defs.sh
source $GroupDefs

# Show help info. It needs $ScriptName to be defined.
Help $@

# If (more) arguments were passed, these are one or more selected system names.
if [ $# -gt 0 ]; then
	SystemNameList=("$@");
fi


# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

cd "$ScriptDir/$GroupDir"

# This function configure the system with name specified as first argument.
configure()
{
	local sysName=$( FormalSysName $1 )
	local sysNameUpper=$( SysNameUpper $sysName );
	local configCmd=$( SysConfigure $sysName ); 

	#echo ${QmakeCmd}

	( echo "${ScriptName}: CONFIGURE ${sysNameUpper} with '${configCmd}'"; eval $configCmd; )
	( echo "${ScriptName}: CONFIGURE ${sysNameUpper} completed"; echo; echo)
}


# Run down the list of system names and do a configure() on each of them.
for name in ${SystemNameList[@]}; do 
	configure $name
done

echo "${ScriptName}: done."

