#!/bin/bash

# ----------------------------------------------------------------------
# Documentation
# ----------------------------------------------------------------------
#
#


# ----------------------------------------------------------------------
# Globals
# ----------------------------------------------------------------------

Vers="(v1)"
ArgCt=$#
GroupDir="../.."

ScriptDir=$(dirname $0 | tr -d \\r)
ScriptName=$(basename $0 .sh)

# Get the group system definitions and source them.
GroupDefs=$ScriptDir/group-defs.sh
source $GroupDefs

# Show help info. It needs $ScriptName to be defined.
Help $@


# First test for qmake debug/release mode flags.
if [ $# -gt 0 ]; then
   if [ "$1" = "debug" ];   then QmakeReleaseDebug=debug;   shift; fi;
   if [ "$1" = "release" ]; then QmakeReleaseDebug=release; shift; fi;
fi

# If (more) arguments were passed, these are one or more selected system names.
if [ $# -gt 0 ]; then
	SystemNameList=("$@");
fi



# ----------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------


# Main checkout function.
diff() 
{
	local sysName=$( FormalSysName $1 )
	local sysSvnUrl=$( SysSvnServer $sysName )
	local sysSvnPath=$( SysSvnFolder $sysName )
	local sysSvnVers=$( SysSvnVersion $sysName )
	local sysLocalDir=$GroupDir/$sysName
	local trunkSvnUrl="$sysSvnUrl/$sysSvnPath/trunk"
	local answ


	if [ -e "$sysLocalDir" ]; then

		# Get system's current svn URL.
		curSvnUrl=$( cd $sysLocalDir; svn info | grep '^URL:' | tr -d \\r)
		curSvnUrl=${curSvnUrl#URL: *}

		echo "------------------------------------------------"
		read -p "$ScriptName: ready for diff '$sysName' ($curSvnUrl) against trunk [enter]: " answ
		( cd $sysLocalDir; svn diff --old $curSvnUrl --new $trunkSvnUrl )
		echo "$ScriptName: end of diff output for $sysName ($curSvnUrl)."
	fi
}


# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

# Make group dir absolute.
cd $ScriptDir/$GroupDir
GroupDir=$(pwd)

# Run down the list of system names and do a diff() on each of them. 

for name in ${SystemNameList[@]}; do 
	diff $name
done

echo "${ScriptName}: done."


