#!/bin/bash 


# ----------------------------------------------------------------------
# Documentation
# ----------------------------------------------------------------------
#
# Shows the meta data as defined in group-defs.sh for each of the 
# systems in the group.
#


# ----------------------------------------------------------------------
# Globals
# ----------------------------------------------------------------------

Vers="(v2)"
ArgCt=$#
GroupDir="../.."

ScriptDir=$(dirname $0 | tr -d \\r)
ScriptName=$(basename $0 .sh)

# Get the group system definitions and source them.
GroupDefs=$ScriptDir/group-defs.sh
source $GroupDefs

# Show help info. It needs $ScriptName to be defined.
Help $@


# First test for qmake debug/release mode flags.
if [ $# -gt 0 ]; then
   if [ "$1" = "debug" ];   then QmakeReleaseDebug=debug;   shift; fi;
   if [ "$1" = "release" ]; then QmakeReleaseDebug=release; shift; fi;
fi

# If (more) arguments were passed, these are one or more selected system names.
if [ $# -gt 0 ]; then
	SystemNameList=("$@");
fi


# ----------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------

showInfo() 
{
	local sysName=$( FormalSysName $1 )
	local sysSvnUrl=$( SysSvnServer $sysName )
	local sysSvnPath=$( SysSvnFolder $sysName )
	local sysSvnVers=$( SysSvnVersion $sysName )
	local sysLocalDir=$GroupDir/$sysName
	local formalSvnUrl currentSvnUrl answ

	formalSvnUrl="$sysSvnUrl/$sysSvnPath/$sysSvnVers"
	currentSvnUrl="-"
	if [ -e $sysLocalDir ]; then 
		currentSvnUrl="$( svn info $sysLocalDir | grep URL: | tr -d \\r )"
	fi

	echo "------------------------------------------------"
	echo -n "system name:       $sysName"

	if [ $sysName = $SystemMain ]; then echo -n "  [main system]"; fi
	if [ ! -e $sysLocalDir ]; then echo -n "  [NOT FOUND]"; fi
	echo " "

	echo "current svn-url:   ${currentSvnUrl#URL: *}"
	echo "formal svn-url:    $formalSvnUrl"
	echo "clean command:     $( SysClean $sysName )"
	echo "configure command: $( SysConfigure $sysName )"
	echo "make command:      $( SysMake $sysName )"
	( cd $sysName; echo -e "changed files:     $(svn stat | grep -c ^)" )
	echo " "
	
}




# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

# Make group dir absolute.
cd $ScriptDir/$GroupDir
GroupDir=$(pwd)


echo "${ScriptName}: group dir: $GroupDir."


# Run down the list of system names and do an update() on each of them. 
for name in ${SystemNameList[@]}; do 
	showInfo $name
done

echo "${ScriptName}: done."

