#!/bin/bash

# ----------------------------------------------------------------------
# Documentation
# ----------------------------------------------------------------------
#
# Generate all information required to comply with the LibAV license:
# - Generate diff with the original sources (original sources found in 
#   svn branches\base
#


# ----------------------------------------------------------------------
# Globals
# ----------------------------------------------------------------------

Vers="(v1)"
ArgCt=$#
GroupDir="../.."

ScriptDir=$(dirname $0 | tr -d \\r)
ScriptName=$(basename $0 .sh)

# Get the group system definitions and source them.
GroupDefs=$ScriptDir/group-defs.sh
source $GroupDefs

# Show help info. It needs $ScriptName to be defined.
Help $@

# If (more) arguments were passed, these are one or more selected system names.
if [ $# -gt 0 ]; then
	SystemNameList=("$@");
fi


# ----------------------------------------------------------------------------------------
#                                           DEFINES
# ----------------------------------------------------------------------------------------

# Defines
System_nexlibavversion=(		9.10						)
System_nexlibavbasesvn=(		svn://svnsrv/ext/nexlibav/tags/libav-		)
System_generatedchangesfileName=(	libav-gv-changes.txt				)

Tar_filename_base=(			nexlibav_sources				)
Tar_excludefiles_debug=(		'--exclude="*.o" --exclude="*.d" --exclude="*.pc" --exclude="Debug" --exclude="Release" --exclude="*.a" '	)
Tar_excludefiles_bin=(			'--exclude="*.so*" --exclude="*.pc" --exclude="*.gz" --exclude="*.tar" --exclude="bin" '			)
Tar_excludefiles_svn=(			'--exclude=".svn" ' )

#--exclude=".*" --exclude=".svn" 


# ----------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------


# Main difference function.
diff() 
{
	local sysName=$( FormalSysName $1 )
	local sysSvnUrl=$( SysSvnServer $sysName )
	local sysSvnPath=$( SysSvnFolder $sysName )
	local sysSvnVers=$( SysSvnVersion $sysName )
	
	# Store only once	
	local sysChangesFile=$sysDir/$System_generatedchangesfileName

	echo "$ScriptName: Generating changes from '$sysSvnUrl/$sysSvnPath/$sysSvnVers' and '$System_nexlibavbasesvn$System_nexlibavversion', please wait..."
	(svn diff $sysSvnUrl/$sysSvnPath/$sysSvnVers $System_nexlibavbasesvn$System_nexlibavversion > $sysChangesFile)
	echo "$ScriptName: Finished generating changefile '$sysChangesFile'."
}


# Main package sources  function.
package() 
{
	local tarName="$Tar_filename_base"_"$1.tar.gz"
	echo "$ScriptName: Creating sources tar-ball, please wait..."
	(tar czf $tarName * $Tar_excludefiles_debug $Tar_excludefiles_bin $Tar_excludefiles_svn)
	echo "$ScriptName: Finished creating tar ball '$tarName'."
}

# Remove the changes file
remove()
{
	local sysChangesFile=$sysDir/$System_generatedchangesfileName
	(rm $sysChangesFile)
	echo "$ScriptName: Removed changefile '$sysChangesFile'."
}

# Check all source files for missing license blocks
checkheaders()
{
	echo "$ScriptName: The license(s) of the following files should be checked:"
	echo -e -n "\e[1;31m"
	# Note: Do not check files under 100 bytes (probably a single-include-only-file)
	find . -size +100c -name "*.c" | xargs grep -i -L "Free Software Foundation\|Permission is hereby granted\|THE SOFTWARE IS PROVIDED \"AS IS\"\|Permission is granted to anyone to use this software for any purpose"
	find . -size +100c -name "*.h" -not -name 'math.h' -not -name 'cmdutils_common_opts.h' | xargs grep -i -L "Free Software Foundation\|Permission is hereby granted\|THE SOFTWARE IS PROVIDED \"AS IS\"\|Permission is granted to anyone to use this software for any purpose\|/* Automatically generated\|/* Generated by"
	echo -e -n "\e[0m"
}


# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

# Make group dir absolute.
cd $ScriptDir/$GroupDir
GroupDir=$(pwd)
sysName=${SystemNameList[0]}
sysDir=$GroupDir/$sysName
cd $sysDir # Now in the nexlibav dir


# Get the version number
localext=$(cat gv_version.txt)

echo "${ScriptName}: Starting..."

diff ${SystemNameList[0]} $SystemSvn_nexlibavbase
package $localext
#remove
checkheaders

echo "${ScriptName}: Done."




