#!/bin/bash 

# ----------------------------------------------------------------------
# Documentation
# ----------------------------------------------------------------------
#
#


# ----------------------------------------------------------------------
# Globals
# ----------------------------------------------------------------------

Vers="(v1)"
ArgCt=$#
GroupDir="../.."

ScriptDir=$(dirname $0| tr -d \\r)
ScriptName=$(basename $0 .sh)

# Get the group system definitions and source them.
GroupDefs=$ScriptDir/group-defs.sh
source $GroupDefs

# Show help info. It needs $ScriptName to be defined.
Help $@


# First test for qmake debug/release mode flags.
if [ $# -gt 0 ]; then
   if [ "$1" = "debug" ];   then QmakeReleaseDebug=debug;   shift; fi;
   if [ "$1" = "release" ]; then QmakeReleaseDebug=release; shift; fi;
fi

# If (more) arguments were passed, these are one or more selected system names.
if [ $# -gt 0 ]; then
	SystemNameList=("$@");
fi


# ----------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------

# This function does a 'mvdt' on a given path.
mvdt()
{
	local verbose=0
	local hide=""

	if [ $# = 0 ]; then
	   echo
	   echo "mvdt (ver. 2.3) usage: mvdt [-h] [-v] <file-or-dir> ..."
	   exit 1
	fi
	
	local stamp1=`date +%y%m%d`
	local stamp2=`date +%y%m%d:%H%M%S`
	
	if [ "$1" = "-v" ]; then verbose=1; shift; fi
	if [ "$1" = "-h" ]; then hide="."; shift; fi
	if [ "$1" = "-v" ]; then verbose=1; shift; fi
	
	for file do
		# Truncate optional trailing slash from $file
		local file=$(dirname ${file}/dummy)
		
		local stamp=$stamp1
		if [ -e ${file}.${stamp} ]; then stamp=$stamp2; fi
		mv $file ${hide}${file}.${stamp}
		if [ $verbose = 1 ]; then echo "mvdt: $file --> ${hide}${file}.${stamp}"; fi
	done
}



# Main checkout function.
checkout() 
{
	local sysName=$( FormalSysName $1 )
	local sysSvnUrl=$( SysSvnServer $sysName )
	local sysSvnPath=$( SysSvnFolder $sysName )
	local sysSvnVers=$( SysSvnVersion $sysName )
	local sysLocalDir=$GroupDir/$sysName
	local answ

	trunkSvnUrl="$sysSvnUrl/$sysSvnPath/trunk"

	echo "------------------------------------------------"
	echo "$ScriptName: checking for $sysName from $trunkSvnUrl"

	if [ -e "$sysLocalDir" ]; then

		# Get system's current svn URL.
		curSvnURL=$( cd $sysLocalDir; svn info | grep '^URL:' | tr -d \\r )
		curSvnURL=${curSvnURL#URL: *}

		# Consider moving current system away if it wasn't checked out from trunk.
		if [ $curSvnURL != $trunkSvnUrl ]; then

			echo "$ScriptName: target '$sysName' exists, sourced from  $curSvnURL"
			read -p "$ScriptName: MOVE AWAY target and checkout from trunk? [y/SKIP]  " answ

			if [ "$answ" != "y" ]; then 
				echo "$ScriptName: target $sysName left untouched"
				return; 
			fi

			echo "$ScriptName: moving away original target dir $sysLocalDir"
			mvdt $sysLocalDir
		fi
	fi

	svn checkout $trunkSvnUrl $sysLocalDir
}



# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

# Make group dir absolute.
cd $ScriptDir/$GroupDir
GroupDir=$(pwd)

# Show group dir, ask to continue.
echo
read -p "$ScriptName $Vers: 'trunketize' systems in group dir '$GroupDir'? [y/N] " answ
if [ "$answ" != "y" ]; then exit; fi


# Run down the list of system names and do a checkout() on each of them. 
# Ignore the main system here.

for name in ${SystemNameList[@]}; do 
	formalName=$( FormalSysName $name )

	if [ ! "$SystemMain" = "$formalName" ]; then 
		checkout $name
	fi
done

echo "${ScriptName}: done."
