#!/bin/bash


# ----------------------------------------------------------------------
# Documentation
# ----------------------------------------------------------------------
#
# Does an 'svn update' for each of the systems in the group. 
# User is aksed for each update.
#


# ----------------------------------------------------------------------
# Globals
# ----------------------------------------------------------------------

Vers="(v1)"
ArgCt=$#
GroupDir="../.."

ScriptDir=$(dirname $0 | tr -d \\r)
ScriptName=$(basename $0 .sh)

# First test for qmake debug/release mode flags.
if [ $# -gt 0 ]; then
   if [ "$1" = "debug" ];   then QmakeReleaseDebug=debug;   shift; fi;
   if [ "$1" = "release" ]; then QmakeReleaseDebug=release; shift; fi;
fi

# Get the group system definitions and source them.
GroupDefs=$ScriptDir/group-defs.sh
source $GroupDefs

# Show help info. It needs $ScriptName to be defined.
Help $@

# If (more) arguments were passed, these are one or more selected system names.
if [ $# -gt 0 ]; then
	SystemNameList=("$@");
fi

# ----------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------

update() 
{
	local sysName=$( FormalSysName $1 )
	local sysSvnUrl=$( SysSvnServer $sysName )
	local sysSvnPath=$( SysSvnFolder $sysName )
	local sysSvnVers=$( SysSvnVersion $sysName )
	local sysLocalDir=$GroupDir/$sysName
	local formalSvnUrl currentSvnUrl answ

	formalSvnUrl="$sysSvnUrl/$sysSvnPath/$sysSvnVers"
	currentSvnUrl="$( svn info "$sysLocalDir" | grep URL: | tr -d \\r )"
	currentSvnUrl=${currentSvnUrl#URL: *}

	echo "------------------------------------------------"

	if [ "$currentSvnUrl" != "$formalSvnUrl" ]; then
		echo "$ScriptName: WARNING: $sysName should be sourced from:    $formalSvnUrl"
		echo "$ScriptName: WARNING: $sysName is currently sourced from: $currentSvnUrl"
	fi 

	read -p "$ScriptName: svn update $sysName from $currentSvnUrl? [y/SKIP] " answ

	if [ "$answ" == "y" ]; then
		( cd "$sysLocalDir"; svn update )
	fi  
}




# ----------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------

# Make group dir absolute.
cd $ScriptDir/$GroupDir
GroupDir=$(pwd)

# Show group dir, ask to continue.
echo
read -p "$ScriptName $Vers: svn update systems in group dir '$GroupDir'? [y/N] " answ
if [ "$answ" != "y" ]; then exit; fi


# Run down the list of system names and do an update() on each of them. 
for name in ${SystemNameList[@]}; do 
	update $name
done

echo "${ScriptName}: done."

